@@ -55,19 +55,23 @@ class RedisServerAdmin(admin.ModelAdmin):
             return mark_safe('<br>'.join(l for _, l in sorted(output, reverse=True)))
         else:
             return 'n/a'
+
     slowlog.allow_tags = True
     slowlog.long_description = _('Slowlog')
 
     def status(self, obj):
         return obj.stats['status']
+
     status.long_description = _("Status")
 
     def memory(self, obj):
         return obj.stats['memory']
+
     memory.long_description = _("Memory")
 
     def clients(self, obj):
         return obj.stats['clients']
+
     clients.long_description = _("Clients")
 
     def tools(self, obj):
@@ -75,6 +79,7 @@ class RedisServerAdmin(admin.ModelAdmin):
             reverse("admin:redisboard_redisserver_inspect", args=(obj.id,)),
             unicode(_("Inspect"))
         ))
+
     tools.allow_tags = True
     tools.long_description = _("Tools")
 
@@ -86,6 +91,7 @@ class RedisServerAdmin(admin.ModelAdmin):
         if output:
             return mark_safe('<dl class="details">%s</dl>' % ''.join(output))
         return 'n/a'
+
     details.allow_tags = True
     details.long_description = _("Details")
 
@@ -113,15 +119,13 @@ class RedisServerAdmin(admin.ModelAdmin):
             output.append('<dt>%s</dt><dd>%s</dd>' % (k, v))
 
         return mark_safe('<dl class="details">%s</dl>' % ''.join(output))
+
     cpu_utilization.allow_tags = True
     cpu_utilization.long_description = _('CPU Utilization')
 
     def get_urls(self):
         urlpatterns = super(RedisServerAdmin, self).get_urls()
-        try:
-            from django.conf.urls import url
-        except ImportError:
-            from django.conf.urls.defaults import url
+        from django.urls import path
 
         def wrap(view):
             def wrapper(*args, **kwargs):
@@ -129,10 +133,7 @@ class RedisServerAdmin(admin.ModelAdmin):
 
             return update_wrapper(wrapper, view)
 
-        return [url(r'^(\d+)/inspect/$',
-                    wrap(self.inspect_view),
-                    name='redisboard_redisserver_inspect')
-                ] + urlpatterns
+        return [path('<int:server_id>/inspect/', wrap(self.inspect_view), name='redisboard_redisserver_inspect')] + urlpatterns
 
     def inspect_view(self, request, server_id):
         server = get_object_or_404(RedisServer, id=server_id)
